<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class Album extends Entity
{
	public  $AlbumID			= -1;
	public  $GroupID			= -1;
	public  $UserID				= -1;
	public  $OrganizationID		= -1;
	public  $CommunityID		= -1;
	public  $AlbumName			= '';
	public  $AlbumDescription	= '';
	public  $AlbumPrivacy		= PRIVACY_PUBLIC;

	private $CoverPhoto1 		= null;


    public function setCover($photo)
    {
        $this->CoverPhoto1 = $photo;
    }

    public function getCover()
    {
        return $this->CoverPhoto1;
    }

    public function setOwner($type, $id)
    {
        global $user;
        switch ($type)
        {
            case 'user':
                $this->OrganizationID = -1;
                $this->GroupID = -1;
                $this->CommunityID = -1;
                $this->UserID = $id;
                break;
            case 'group':
                $this->OrganizationID = -1;
                $this->GroupID = $id;
                $this->CommunityID = -1;
                $this->UserID = $user->UserID;
                break;
            case 'organization':
                $this->OrganizationID = $id;
                $this->GroupID = -1;
                $this->CommunityID = -1;
                $this->UserID = $user->UserID;
                break;
            case 'community':
                $this->OrganizationID = -1;
                $this->GroupID = -1;
                $this->CommunityID = $id;
                $this->UserID = $user->UserID;
                break;
        }
    }

    public function getOwner()
    {
        global $user;
        $result = $user;

        if ($this->GroupID != -1)
        {
            $result = new Group($this->GroupID);
        }
        elseif ($this->OrganizationID != -1)
        {
            $result = new Organization($this->OrganizationID);
        }
        elseif ($this->CommunityID != -1)
        {
            $result = new Community($this->CommunityID);
        }
        elseif ($this->UserID != -1)
        {
            $result = new User($this->UserID);
        }
        return $result;
    }
    
    public function createAlbumPrivacyConnection($entity, $entity_id)
    {
		$album_id = $this->AlbumID;
		$field = $entity . 'ID';
		$db = DBConnect::getInstance();
		$db->insert('albumprivacyconnection', array('AlbumID' => $album_id, $field => $entity_id));
	}

	public function checkAlbumPrivacyConnection()
	{
        global $user;
		$result = false;

		$album_id = $this->AlbumID;
		$user_id = $user->UserID;
		$db = DBConnect::getInstance();

		$rs = $db->query("SELECT COUNT(*) AS cnt FROM `albumprivacyconnection` WHERE AlbumID=%d AND UserID=%d", $album_id, $user_id);
		if ($rs->Data[0]['cnt'] != 0)
		{
			$result = true;
			return $result;
		}

		$rs =
		$db->query(
			"SELECT COUNT(*) AS cnt FROM `albumprivacyconnection` AS apc
			 WHERE apc.AlbumID = %d
			 AND apc.GroupID IN
			 (
				SELECT c.GroupID FROM `connection` AS c
				WHERE (c.UserID = %d) AND (c.GroupID > 0)
			 )",
		$album_id, $user_id);
		if ($rs->Data[0]['cnt'] != 0)
		{
			$result = true;
			return $result;
		}

		$rs =
		$db->query(
			"SELECT COUNT(*) AS cnt FROM `albumprivacyconnection` AS apc
			 WHERE apc.AlbumID = %d
			 AND apc.OrganizationID IN
			 (
				SELECT c.OrganizationID FROM `connection` AS c
				WHERE (c.UserID = %d) AND (c.OrganizationID > 0)
			 )",
		$album_id, $user_id);
		if ($rs->Data[0]['cnt'] != 0)
		{
			$result = true;
			return $result;
		}

		return $result;
	}

    public function checkPermission($action)
    {
    	global $user;

        $view   = true;
        $edit   = false;
        $delete = false;
        $upload = false;

        $object = $this->getOwner();
        $entity = get_class($object);

        if ($entity == 'User')
	    {
        	if ($object->UserID == $user->UserID)
        	{
			    $edit   = true;
			    $delete = true;
			    $upload = true;
        	}
        	else if ($this->AlbumPrivacy != PRIVACY_PUBLIC)
        	{
        		$view = false;
        	}
	    }
	    else
	    {
	    	if ($object->{$entity . 'Status'} != GROUP_STATUS_PUBLIC && $object->{$entity . 'Status'} != ORGANIZATION_STATUS_PUBLIC)
	    	{
		        if (!$object->hasMember($user->UserID))
		        {
	        		$view = false;
		        }
			}

	        if ($object->userIsAdmin($user->UserID))
	        {
	        	$view   = true;
			    $edit   = true;
			    $delete = true;

				if ($object->isOwner($user->UserID))
				{
			    	$upload = true;
				}
	        }
            else
            {
                $edit = ($this->UserID == $user->UserID);
            }
	    }

        if ($this->AlbumPrivacy != PRIVACY_PUBLIC)
        {
        	$view = ($view || Connection::checkAlbumPrivacy($this->AlbumID, $user->UserID));
		}

		switch ($action)
        {
            case 'view':
                $result = $view;
            	break;

            case 'edit':
            	$result = $edit;
            	break;

            case 'delete':
                $result = $delete;
            	break;

            case 'upload':
                $result = $upload;
            	break;
        }

        return $result;
    }

    public static function getAlbumsByType($type = 'user', $id = -1)
    {
        switch ($type)
        {
            case 'user':
                return Album::getUserAlbums($id);
                break;
            case 'group':
                return Album::getGroupAlbums($id);
                break;
            case 'organization':
                return Album::getOrganizationAlbums($id);
                break;
            case 'community':
                return Album::getCommunityAlbums($id);
                break;
        }
        return array ();
    }

    public static function getUserAlbums($userID)
    {
        $return = array();
        $db = DBConnect::getInstance();
         $query = $db->query('SELECT
             a.AlbumID, a.UserID,
             a.AlbumName, a.AlbumDescription, a.AlbumPrivacy,
             p.PhotoPath as CoverPhoto
             FROM album a LEFT JOIN photo p on (a.AlbumID = p.AlbumID) AND (p.PhotoIsCover = 1)
             WHERE a.UserID = %d', $userID);
        foreach ($query->Data as $row)
        {
            $album = new Album();
            $album->populateFromArray($row);
            $album->setCover($row['CoverPhoto'] ? PATH_ALBUM_PICS . '/' . $album->AlbumID . '/previews/' . $row['CoverPhoto'] : ICON_PHOTO);
            $return[] = $album;
        }
        return $return;
    }

    public static function getGroupAlbums($groupID)
    {
        $return = array();
        $db = DBConnect::getInstance();
         $query = $db->query('SELECT
             a.*,
             p.PhotoPath as CoverPhoto
             FROM album a LEFT JOIN photo p on (a.AlbumID = p.AlbumID) AND (p.PhotoIsCover = 1)
             WHERE a.GroupID = %d', $groupID);
        foreach ($query->Data as $row)
        {
            $album = new Album();
            $album->populateFromArray($row);
            $album->setCover($row['CoverPhoto'] ? PATH_ALBUM_PICS . '/' . $album->AlbumID . '/previews/' . $row['CoverPhoto'] : ICON_PHOTO);
            $return[] = $album;
        }
        return $return;
    }

    public static function getOrganizationAlbums($organizationID)
    {
        $return = array();
        $db = DBConnect::getInstance();
         $query = $db->query('SELECT
             a.AlbumID, a.UserID, a.OrganizationID,
             a.AlbumName, a.AlbumDescription, a.AlbumPrivacy,
             p.PhotoPath as CoverPhoto
             FROM album a LEFT JOIN photo p on (a.AlbumID = p.AlbumID) AND (p.PhotoIsCover = 1)
             WHERE a.OrganizationID = %d', $organizationID);
        foreach ($query->Data as $row)
        {
            $album = new Album();
            $album->populateFromArray($row);
            $album->setCover($row['CoverPhoto'] ? PATH_ALBUM_PICS . '/' . $album->AlbumID . '/previews/' . $row['CoverPhoto'] : ICON_PHOTO);
            $return[] = $album;
        }
        return $return;
    }

    public static function getCommunityAlbums($communityID)
    {
        $return = array();
        $db = DBConnect::getInstance();
         $query = $db->query('SELECT
             a.AlbumID, a.CommunityID, a.UserID,
             a.AlbumName, a.AlbumDescription, a.AlbumPrivacy,
             p.PhotoPath as CoverPhoto
             FROM album a LEFT JOIN photo p on (a.AlbumID = p.AlbumID) AND (p.PhotoIsCover = 1)
             WHERE a.CommunityID = %d', $communityID);
        foreach ($query->Data as $row)
        {
            $album = new Album();
            $album->populateFromArray($row);
            $album->setCover($row['CoverPhoto'] ? PATH_ALBUM_PICS . '/' . $album->AlbumID . '/previews/' . $row['CoverPhoto'] : ICON_PHOTO);
            $return[] = $album;
        }
        return $return;
    }

    public function getPhotosCount()
    {
        $db = DBConnect::getInstance();
        $res = $db->query("select count(PhotoID) as `c` from `photo` where `AlbumID` = %d", $this->AlbumID);
        return $res->Data['0']['c'];
    }

    public function getPhotos($first = 0, $last = 999999)
    {
        return Photo::getAlbumPhotos($this->AlbumID, $first, $last);
    }

    public function clearCover()
    {
        $db = DBConnect::getInstance();
        $db->query('update photo set PhotoIsCover = 0 where AlbumID = %d', $this->AlbumID);
    }

    public function delete()
    {
        cmn_remove_directory(PATH_ALBUM_PICS . '/' . $this->AlbumID . '/previews');
        cmn_remove_directory(PATH_ALBUM_PICS . '/' . $this->AlbumID . '/original');
        cmn_remove_directory(PATH_ALBUM_PICS . '/' . $this->AlbumID);
        cmn_remove_directory('./tmp/' . $this->AlbumID);
        Photo::deleteAlbumPhotos($this->AlbumID);
        parent::delete();
    }

	public static function getAlbumsCount($ownerEntity, $ownerID)
	{
		$count = 0;

		$db = DBConnect::getInstance();
		switch ($ownerEntity)
		{
			case 'User':
			case 'Group':
			case 'Organization':
				$result = $db->query('select count(*) as cnt from album where %f = %d', $ownerEntity . 'ID', $ownerID);
				$count = intval($result->Data[0]['cnt']);
		}
		return $count;
	}

    public function getTags()
    {
    	return Tag::getTags(TAG_TYPE_PHOTO_ALBUM, $this->AlbumID);
    }

}
?>