<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class Connection extends Entity
{
	public $ConnectionID	= -1;
	public $CommunityID		= -1;
	public $ToCommunityID	= -1;

	public $UserID			= -1;
	public $ToUserID		= -1;
	public $OrganizationID	= -1;
	public $ToOrganizationID= -1;

	public $GroupID			= -1;
	public $ToGroupID		= -1;

	public $AlbumID			= -1;
	public $VideoAlbumID	= -1;

	public $UserStatus		= MEMBER_STATUS_ACTIVE;
	public $ConnectionType	= CONNECTIONTYPE_MEMBER;
	public $Flags			= 0;
    public $Created         = CURRENT_TIME;

	public $PrivacyFlags	= PRIVACY_FLAGS_ALL;


	public function getTarget($obj)
	{
		$classes = array('User', 'Organization', 'Group', 'Community');

		if (($index = array_search(get_class($obj), $classes)) !== false)
		{
			unset($classes[$index]);
		}

		foreach ($classes as $class)
		{
			if ($this->{$class . 'ID'} != -1)
			{
				return Entity::getObject($class, $this->{$class . 'ID'});
			}
		}

		if ($this->ToUserID != -1)
		{
			if ($this->ToUserID == $obj->UserID)
			{
				return new User($this->UserID);
			}
			else
			{
				return new User($this->ToUserID);
			}
		}

		if ($this->ToGroupID != -1)
		{
			if ($this->ToGroupID == $obj->GroupID)
			{
				return new Group($this->GroupID);
			}
			else
			{
				return new Group($this->ToGroupID);
			}
		}

		if ($this->ToOrganizationID != -1)
		{
			if ($this->ToOrganizationID == $obj->OrganizationID)
			{
				return new Organization($this->OrganizationID);
			}
			else
			{
				return new Organization($this->ToOrganizationID);
			}
		}


		return null;
	}

	// $where = array(field => value, ...)
	// value may be 'null' or 'not null' or array

	// $order = array(field, field, ...)
	public static function getConnections($where = array(), $order = array(), $limit = 0)
	{
		$db = DBConnect::getInstance();
		$return = array();

		$query = 'select distinct * from `connection`';
		if ($count = count($where))
		{
			$query .= ' where ';
			foreach ($where as $field => $value)
			{
				$count--;

				$query .= '`' . ud_sanitize_db($field) . '`' .
					(
						($value == 'not null' || $value == 'null') ?
							' is ' . $value :
							(
								($value == '<> -1' || $value == '<> ' . CONNECTIONFLAG_STATUS_SUSPEND) ? $value :
							    (
							    is_array($value) ?
								    ' in (' . join(',', $value) . ')' :
									' = \'' . ud_sanitize_db($value) . '\''
								)
							)
					) .
					($count ? ' and ' : '');

			}
		}

		if (count($order))
		{
			$order = ud_sanitize_db($order);
			$query .= ' order by ' . join(' , ', $order);
		}

		if ($limit)
		{
			$query .= ' limit ' . ud_sanitize_db($limit);
		}

		try
		{
			$result = $db->query($query);
		}
		catch (Exception $ex)
		{
			return $return;
		}

		foreach ($result->Data as $row)
		{
			$obj = new Connection();
			$obj->populateFromArray($row);
			$return[] = $obj;
		}

		return $return;
	}

	public static function getUserBuddyConnections($userID)
	{
		$db = DBConnect::getInstance();
		$result = $db->query('select * from `connection` where UserID = %d and ToUserID > 0 and ConnectionType = %d order by Created',
			$userID, CONNECTIONTYPE_BUDDY);

		$return = array();

		foreach ($result->Data as $row)
		{
			$obj = new Connection();
			$obj->populateFromArray($row);
			$return[] = $obj;
		}

		return $return;
	}

	public function getToUser()
	{
		$user = new User();

		if ($this->ToUserID != -1)
		{
			$user = new User($this->ToUserID);
		}

		return $user;
	}

	public function getUser()
	{
		$user = new User();

		if ($this->UserID != -1)
		{
			$user = new User($this->UserID);
		}

		return $user;
	}

	public static function getUserConnections($userID)
	{
		$db = DBConnect::getInstance();
		$result = $db->query('select * from `connection` where (UserID = %d or ToUserID = %d) and (ConnectionType = %d ' .
			'or ConnectionType = %d or ConnectionType = %d or ConnectionType = %d) order by Created',
			$userID, $userID, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_BUDDY, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER);

		$return = array();

		foreach ($result->Data as $row)
		{
			$obj = new Connection();
			$obj->populateFromArray($row);
			$return[] = $obj;
		}

		return $return;
	}

	public function getOrganization()
	{
		$organization = new Organization();

		if ($this->OrganizationID != -1)
		{
			$organization = new Organization($this->OrganizationID);
		}

		return $organization;
	}

	public function getGroup()
	{
		$group = new Group();

		if ($this->GroupID != -1)
		{
			$group = new Group($this->GroupID);
		}

		return $group;
	}

	public function getCommunity()
	{
		$community = new Community();

		if ($this->CommunityID != -1)
		{
			$community = new Community($this->CommunityID);
		}

		return $community;
	}

	public static function getConnectedUsers($to_user, $name_constraint)
	{
		$result = array();
		$params = array();

		if (!empty($name_constraint))
		{
			$clause = "AND (u.UserLastname LIKE %p or u.UserFirstname LIKE %p)";
			$params = array($name_constraint, $name_constraint);
		}

		$db = DBConnect::getInstance();
		$query = 'SELECT u.* FROM `connection` AS c ' .
				'INNER JOIN `user` AS u ON u.UserID = c.ToUserID ' .
				'WHERE c.UserID = ' . $to_user . ' AND c.ToUserID > 0 ' .
				'AND ConnectionType = ' . CONNECTIONTYPE_BUDDY . ' ' . $clause;

		$rs = $db->query($query, $params);

		foreach ($rs->Data as $row)
		{
			$obj = new User();
			$obj->populateFromArray($row);
			$result[] = $obj;
		}

		return $result;
	}

    public static function getConnectedCommunities($to_user, $name_constraint)
    {
        $result = array();
        $params = array();

        if (!empty($name_constraint))
        {
            $clause = "AND g.CommunityName LIKE %p";
            $params[] = $name_constraint;
        }

        $db = DBConnect::getInstance();
        $query = 'SELECT g.* FROM `connection` AS c ' .
                'INNER JOIN `community` AS g ON g.CommunityID = c.CommunityID ' .
                'WHERE c.UserID = ' . $to_user . ' AND c.CommunityID > 0 ' .
                'AND (ConnectionType = ' . CONNECTIONTYPE_MEMBER . ' or ConnectionType = ' . CONNECTIONTYPE_ADMIN .
                ' or ConnectionType = ' . CONNECTIONTYPE_OWNER . ') ' . $clause;

        $rs = $db->query($query, $params);

        foreach ($rs->Data as $row)
        {
            $obj = new Community();
            $obj->populateFromArray($row);
            $result[] = $obj;
        }

        return $result;
    }

    public static function getConnectedGroups($to_user, $name_constraint)
    {
        $result = array();
        $params = array();

        if (!empty($name_constraint))
        {
            $clause = "AND g.GroupName LIKE %p";
            $params[] = $name_constraint;
        }

        $db = DBConnect::getInstance();
        $query = 'SELECT g.* FROM `connection` AS c ' .
                'INNER JOIN `group` AS g ON g.GroupID = c.GroupID ' .
                'WHERE c.UserID = ' . $to_user . ' AND c.GroupID > 0 ' .
                'AND (ConnectionType = ' . CONNECTIONTYPE_MEMBER . ' or ConnectionType = ' . CONNECTIONTYPE_ADMIN .
                ' or ConnectionType = ' . CONNECTIONTYPE_OWNER . ') ' . $clause;

        $rs = $db->query($query, $params);

        foreach ($rs->Data as $row)
        {
            $obj = new Group();
            $obj->populateFromArray($row);
            $result[] = $obj;
        }

        return $result;
    }

    public static function getConnectedOrganizations($to_user, $name_constraint)
    {
        $result = array();
        $params = array();

        if (!empty($name_constraint))
        {
            $clause = "AND g.OrganizationName LIKE %p";
            $params[] = $name_constraint;
        }

        $db = DBConnect::getInstance();
        $query = 'SELECT g.* FROM `connection` AS c ' .
                'INNER JOIN `organization` AS g ON g.OrganizationID = c.OrganizationID ' .
                'WHERE c.UserID = ' . $to_user . ' AND c.OrganizationID > 0 ' .
                'AND (ConnectionType = ' . CONNECTIONTYPE_MEMBER . ' or ConnectionType = ' . CONNECTIONTYPE_ADMIN .
                ' or ConnectionType = ' . CONNECTIONTYPE_OWNER . ') ' . $clause;

        $rs = $db->query($query, $params);

        foreach ($rs->Data as $row)
        {
            $obj = new Organization();
            $obj->populateFromArray($row);
            $result[] = $obj;
        }

        return $result;
    }

	public static function checkOrganizationGroupConnected($groupID, $orgID)
	{
		$db = DBConnect::getInstance();
		$result = $db->query('select count(*) as cnt from `connection` where ConnectionType in (%d,%d,%d) and ' .
			'(GroupID = %d and ToOrganizationID = %d or OrganizationID = %d and ToGroupID = %d or OrganizationID = %d and GroupID = %d )',
			CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_ADMIN, $groupID, $orgID, $orgID, $groupID, $orgID, $groupID);

		return (intval($result->Data[0]['cnt']) > 0);
	}


	public static function checkGroupsConnected($groupID, $groupID2)
	{
		$db = DBConnect::getInstance();
		$result = $db->query('select count(*) as cnt from `connection` where ConnectionType in (%d,%d,%d) and ' .
			'(GroupID = %d and ToGroupID = %d or GroupID = %d and ToGroupID = %d)',
			CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_ADMIN, $groupID, $groupID2, $groupID2, $groupID);
		return (intval($result->Data[0]['cnt']) > 0);
	}


	public static function checkOrganizationsConnected($orgID, $orgID2)
	{
		$db = DBConnect::getInstance();
		$result = $db->query('select count(*) as cnt from `connection` where ' .
			'ConnectionType = %d and (OrganizationID = %d and ToOrganizationID = %d or OrganizationID = %d and ToOrganizationID = %d)',
			CONNECTIONTYPE_MEMBER, $orgID, $orgID2, $orgID2, $orgID);

		return (intval($result->Data[0]['cnt']) > 0);
	}

	public static function  checkUserPrivacyAccessPrivilegies($privacy_flag, $src_user_id, $dest_user_id)
	{
		$result = false;

		$db = DBConnect::getInstance();
		$query = $db->query("SELECT OnlyMyFlags FROM `user` WHERE UserID = %d", $src_user_id);
		if ($query->Data[0]['OnlyMyFlags'] & $privacy_flag)
		{
			$query = $db->query("SELECT PrivacyFlags FROM `connection` WHERE UserID = %d AND ToUserID = %d AND ConnectionType = %d", $src_user_id, $dest_user_id, CONNECTIONTYPE_PRIVACY);
			if ($query->Data[0]['PrivacyFlags'] & $privacy_flag)
			{
				$result = true;
			}
		}
		else
		{
			$result = true;
		}

		return $result;
	}

	public static function  setUserPrivacyAccessPrivilegies($privacy_flag, $src_user_id, $dest_user_id)
	{
		$connections = Connection::getConnections(array('UserID' => $src_user_id, 'ToUserID' => $dest_user_id, 'ConnectionType' => CONNECTIONTYPE_PRIVACY));
		if (!$connections)
		{
			$connection = new Connection();
			$connection->UserID = $src_user_id;
			$connection->ToUserID = $dest_user_id;
			$connection->ConnectionType = CONNECTIONTYPE_PRIVACY;
			$connection->saveToDB();
		}

		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags | %d WHERE UserID = %d AND ToUserID = %d AND ConnectionType = %d", $privacy_flag, $src_user_id, $dest_user_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags | %d WHERE UserID = %d", $privacy_flag, $src_user_id);
	}

	public static function  dropUserPrivacyAccessPrivilegies($privacy_flag, $user_id)
	{
		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags & ~%d WHERE UserID = %d AND ToUserID > 0 AND ConnectionType = %d", $privacy_flag, $user_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags | %d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  setAllUserPrivacyAccessPrivilegies($privacy_flag, $user_id)
	{
		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags | %d WHERE UserID = %d AND ToUserID > 0 AND ConnectionType = %d", $privacy_flag, $user_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags & ~%d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  setGroupPrivacyAccessPrivilegies($privacy_flag, $user_id, $group_id)
	{
		$connections = Connection::getConnections(array('UserID' => $user_id, 'GroupID' => $group_id, 'ConnectionType' => CONNECTIONTYPE_PRIVACY));
		if (!$connections)
		{
			$connection = new Connection();
			$connection->UserID = $src_user_id;
			$connection->GroupID = $group_id;
			$connection->ConnectionType = CONNECTIONTYPE_PRIVACY;
			$connection->saveToDB();
		}

		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags | %d WHERE UserID = %d AND GroupID = %d AND ConnectionType = %d", $privacy_flag, $user_id, $group_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags | %d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  setOrganizationPrivacyAccessPrivilegies($privacy_flag, $user_id, $organization_id)
	{
		$connections = Connection::getConnections(array('UserID' => $user_id, 'OrganizationID' => $organization_id, 'ConnectionType' => CONNECTIONTYPE_PRIVACY));
		if (!$connections)
		{
			$connection = new Connection();
			$connection->UserID = $src_user_id;
			$connection->OrganizationID = $organization_id;
			$connection->ConnectionType = CONNECTIONTYPE_PRIVACY;
			$connection->saveToDB();
		}

		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags | %d WHERE UserID = %d AND OrganizationID = %d AND ConnectionType = %d", $privacy_flag, $user_id, $organization_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags | %d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  setCommunityPrivacyAccessPrivilegies($privacy_flag, $user_id, $community_id)
	{
		$connections = Connection::getConnections(array('UserID' => $user_id, 'CommunityID' => $community_id, 'ConnectionType' => CONNECTIONTYPE_PRIVACY));
		if (!$connections)
		{
			$connection = new Connection();
			$connection->UserID = $src_user_id;
			$connection->CommunityID = $community_id;
			$connection->ConnectionType = CONNECTIONTYPE_PRIVACY;
			$connection->saveToDB();
		}

		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags | %d WHERE UserID = %d AND CommunityID = %d AND ConnectionType = %d", $privacy_flag, $user_id, $community_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags | %d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  dropGroupPrivacyAccessPrivilegies($privacy_flag, $user_id)
	{
		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags & ~%d WHERE UserID = %d AND GroupID > 0 AND ConnectionType = %d", $privacy_flag, $user_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags | %d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  dropOrganizationPrivacyAccessPrivilegies($privacy_flag, $user_id)
	{
		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags & ~%d WHERE UserID = %d AND OrganizationID > 0 AND ConnectionType = %d", $privacy_flag, $user_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags | %d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  dropCommunityPrivacyAccessPrivilegies($privacy_flag, $user_id)
	{
		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags & ~%d WHERE UserID = %d AND CommunityID > 0 AND ConnectionType = %d", $privacy_flag, $user_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags | %d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  setAllGroupPrivacyAccessPrivilegies($privacy_flag, $user_id)
	{
		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags | %d WHERE UserID = %d AND GroupID > 0 AND ConnectionType = %d", $privacy_flag, $user_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags & ~%d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	public static function  setAllOrganizationPrivacyAccessPrivilegies($privacy_flag, $user_id)
	{
		$db = DBConnect::getInstance();
		$db->query("UPDATE `connection` SET PrivacyFlags = PrivacyFlags | %d WHERE UserID = %d AND OrganizationID > 0 AND ConnectionType = %d", $privacy_flag, $user_id, CONNECTIONTYPE_PRIVACY);
		$db->query("UPDATE `user` SET OnlyMyFlags = OnlyMyFlags & ~%d WHERE UserID = %d", $privacy_flag, $user_id);
	}

	private static function checkPrivacy($entity, $entityID, $userID, $connType)
	{
		$field = '';
		if ($entity == 'User')
		{
			$field = 'To';
		}
		$field .= $entity . 'ID';

		$db = DBConnect::getInstance();
		$result = $db->query('select count(*) as cnt from `connection` c ' .
			'left join `connection` cg on c.GroupID = cg.GroupID and cg.UserID <> -1 and cg.ConnectionType in (%d,%d,%d) ' .
			'left join `connection` co on c.OrganizationID = co.OrganizationID and co.UserID <> -1 and co.ConnectionType in (%d,%d,%d) ' .
			'left join `connection` cc on c.CommunityID = cc.CommunityID and cc.UserID <> -1 and cc.ConnectionType in (%d,%d,%d) ' .
			'where ((cg.UserID = %d or co.UserID = %d or cc.UserID = %d) or (c.ConnectionType = %d and c.UserID = %d))' .
			'and c.%f = %d',

			CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_MEMBER,
			CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_MEMBER,
			CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_MEMBER,
			$userID, $userID, $userID, $connType, $userID,
			$field, $entityID);

		return intval($result->Data[0]['cnt']) > 0;
	}

	private static function createPrivacyConnection($entity, $entityID, $targetEntity, $targetEntityID, $connType)
	{
		$field = '';
		if ($entity == 'User')
		{
			$field = 'To';
		}
		$field .= $entity . 'ID';

		$db = DBConnect::getInstance();
		$db->delete('connection', '%f = %d and %f = %d and ConnectionType = %d', $field, $entityID,
			$targetEntity . 'ID', $targetEntityID, $connType);

		$connection = new Connection();
		$connection->{$field} = $entityID;
		$connection->{$targetEntity . 'ID'} = $targetEntityID;
		$connection->ConnectionType = $connType;

		$connection->saveToDB();
	}

	private static function clearPrivacyConnections($entity, $entityID, $connType)
	{
		$field = '';
		if ($entity == 'User')
		{
			$field = 'To';
		}
		$field .= $entity . 'ID';

		$db = DBConnect::getInstance();
		$db->delete('connection', '%f = %d and ConnectionType = %d', $field, $entityID, $connType);
	}

	public static function clearAlbumPrivacy($albumID)
	{
		Connection::clearPrivacyConnections('Album', $albumID, CONNECTIONTYPE_ALBUM_ACCESS);
	}

	public static function clearVideoAlbumPrivacy($albumEntity, $albumEntityID)
	{
		Connection::clearPrivacyConnections($albumEntity, $albumEntityID, CONNECTIONTYPE_ALBUM_ACCESS);
	}

	public static function getAlbumPrivacyConnections($albumID)
	{
		$db = DBConnect::getInstance();
		$result = $db->query('select * from `connection` where AlbumID = %d and ConnectionType = %d',
			$albumID, CONNECTIONTYPE_ALBUM_ACCESS);
		$return = array();

		foreach ($result->Data as $row)
		{
			$obj = new Connection();
			$obj->populateFromArray($row);
			$return[] = $obj;
		}
		return $return;
	}

	public static function getVideoAlbumPrivacyConnections($albumID)
	{
		$db = DBConnect::getInstance();
		$result = $db->query('select * from `connection` where VideoAlbumID = %d and ConnectionType = %d',
			$albumID, CONNECTIONTYPE_ALBUM_ACCESS);
		$return = array();

		foreach ($result->Data as $row)
		{
			$obj = new Connection();
			$obj->populateFromArray($row);
			$return[] = $obj;
		}
		return $return;
	}

	public static function checkAlbumPrivacyConnection($albumEntity, $albumEntityID, $targetEntity, $targetEntityID)
	{
		return Connection::checkPrivacy($albumEntity, $albumEntityID, $$targetEntityID, CONNECTIONTYPE_ALBUM_ACCESS);
	}

	public static function checkAlbumPrivacy($albumID, $userID)
	{
		return Connection::checkPrivacy('Album', $albumID, $userID, CONNECTIONTYPE_ALBUM_ACCESS);
	}

	public static function createAlbumPrivacyConnection($albumID, $targetEntity, $targetEntityID)
	{
		return Connection::createPrivacyConnection('Album', $albumID, $targetEntity, $targetEntityID, CONNECTIONTYPE_ALBUM_ACCESS);
	}

	public static function createVideoAlbumPrivacyConnection($albumEntity, $albumEntityID, $targetEntity, $targetEntityID)
	{
		return Connection::createPrivacyConnection($albumEntity, $albumEntityID, $targetEntity, $targetEntityID, CONNECTIONTYPE_ALBUM_ACCESS);
	}

	public static function clearCalendarPrivacy($calendarEntity, $calendarEntityID)
	{
		Connection::clearPrivacyConnections($calendarEntity, $calendarEntityID, CONNECTIONTYPE_CALENDAR_ACCESS);
	}

	public static function checkCalendarPrivacy($calendarEntity, $calendarEntityID, $userID)
	{
		return Connection::checkPrivacy($calendarEntity, $calendarEntityID, $userID, CONNECTIONTYPE_CALENDAR_ACCESS);
	}

	public static function createCalendarPrivacyConnection($calendarEntity, $calendarEntityID, $targetEntity, $targetEntityID)
	{
		return Connection::createPrivacyConnection($calendarEntity, $calendarEntityID, $targetEntity, $targetEntityID, CONNECTIONTYPE_CALENDAR_ACCESS);
	}
}