<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class Group extends ConnectionEntity
{
	public $GroupID 			= -1;
	public $GroupName 			= '';
	public $GroupDescription	= '';
	public $GroupKeywords		= '';
	public $GroupStatus			= GROUP_STATUS_PUBLIC;
	public $GroupAddress1		= '';
	public $GroupAddress2		= '';
	public $GroupCity			= '';
	public $GroupState			= '';
	public $GroupCountry		= '';
	public $GroupZip			= '';
	public $GroupEmail			= '';
	public $GroupWebAddress		= '';
	public $GroupPhone			= '';
	public $GroupFax			= '';
	public $GroupFavouriteWebsites	= '';
	public $GroupForumID		= -1;
	public $GroupPermissions	= 0;
	public $GroupOwner			= -1;
	public $GroupPicture		= '';
	public $Created				= null;
	public $GroupCreated		= null;
	public $GroupUpdated		= null;
    public $GroupCalendarPrivacy	= CALENDAR_PRIVACY_PUBLIC;
    public $GroupIsNonForProfit	= 0;


    public function __construct($entity_id = -1)
    {
    	parent::__construct($entity_id);
    	foreach ($this as $field_id => $field)
    	{
    		if (is_string($field))
    		{
    			$this->{$field_id} = html_entity_decode($field);
    		}
    	}
    }

    public function getOwnerUser()
    {
    	$owner = $this;
    	while (get_class($owner) != 'User')
    	{
    		$owner = $owner->getOwner();
		}
		return $owner;
	}

    public function getOwnerUserID()
    {
    	$user = $this->getOwnerUser();
    	return $user->UserID;
	}

    public function isPublic()
    {
    	return $this->GroupStatus == GROUP_STATUS_PUBLIC;
    }

    public function isMemberBlocked($member_id)
	{
		$connections = Connection::getConnections
		(
			array
			(
				'UserID'	       	=> $member_id,
				'GroupID'			=> $this->GroupID,
				'UserStatus'		=> MEMBER_STATUS_BLOCKED
			)
		);
		return count($connections) > 0;
	}

    public function isJoinRequested($id, $entity = 'User')
    {
    	return Message::isGroupRequestSent($id, $this->GroupID, $entity);
    }

	public function checkCalendarPrivacy($userID)
	{
		$blnCanSee = true;

		if ($this->GroupCalendarPrivacy != CALENDAR_PRIVACY_PUBLIC)
		{
			$blnCanSee = $this->hasMember($userID);

			if ($this->GroupCalendarPrivacy == CALENDAR_PRIVACY_PROTECTED)
			{
				$blnCanSee = $blnCanSee || Connection::checkCalendarPrivacy('Group', $this->GroupID, $userID);
			}
		}

		return $blnCanSee;
	}

    public function hasMember($userID)
    {
    	$connections = Connection::getConnections(array('ConnectionType' => array(CONNECTIONTYPE_OWNER,
    		CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER),
    		'UserID' => $userID, 'GroupID' => $this->GroupID));

    	return (count($connections) > 0) || User::checkEmployer($userID);
    }

    public function hasGroup($groupID)
    {
    	return Connection::checkGroupsConnected($this->GroupID, $groupID);
    }

    public function hasOrganization($orgID)
    {
    	return Connection::checkOrganizationGroupConnected($this->GroupID, $orgID);
    }

    public function hasCommunity($communityID)
    {
    	$connections = Connection::getConnections(array('ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'CommunityID' => $communityID, 'GroupID' => $this->GroupID));
    	return (count($connections) > 0);
    }

    public function removeMember($userID)
    {
		$connections = Connection::getConnections(array(
			'ConnectionType' => array(CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER),
    		'UserID' => $userID, 'GroupID' => $this->GroupID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}
    }

    public function removeGroup($groupID)
    {
		$connections = Connection::getConnections(array(
			'ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'ToGroupID' => $groupID, 'GroupID' => $this->GroupID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}

		$connections = Connection::getConnections(array(
			'ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'GroupID' => $groupID, 'ToGroupID' => $this->GroupID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}

    }

    public function removeOrganization($orgID)
    {
		$connections = Connection::getConnections(array(
			'ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'OrganizationID' => $orgID, 'GroupID' => $this->GroupID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}
	}

    public function removeCommunity($communityID)
    {
		$connections = Connection::getConnections(array(
			'ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'CommunityID' => $communityID, 'GroupID' => $this->GroupID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}
	}

    public function getEvents()
    {
    	return Event::getGroupEvents($this->GroupID);
    }

	public function getConnections($where = array(), $order = array(), $limit = 0)
	{
		$where['GroupID'] = $this->GroupID;
		return Connection::getConnections($where, $order, $limit);
    }

    public function getMembers()
    {
    	$connections = Connection::getConnections(array('ConnectionType' => array(CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER), 'GroupID' => $this->GroupID));
    	$result = array();
    	foreach ($connections as $conn)
    	{
    		$result[] = new User($conn->UserID);
    	}
    	return $result;
    }

    public function addGroup($groupID, $type = CONNECTIONFLAG_TYPE_UNOFFICIAL)
    {
		if (!$this->hasGroup($groupID))
		{
			$group = new Group($groupID);
			if ($group->GroupID != -1)
			{
		        $connection = new Connection();
		        $connection->ToGroupID = $this->GroupID;
		        $connection->GroupID = $groupID;
		        $connection->ConnectionType = CONNECTIONTYPE_MEMBER;
		        $connection->Flags = $type;
		        $connection->saveToDB();

		        $members = $group->getGroupAdmins();
		        foreach ($members as $member)
		        {
					$this->addAdmin($member->UserID);
				}

		        $members = $this->getGroupAdmins();
		        foreach ($members as $member)
		        {
		        	$group->addAdmin($member->UserID);
				}
			}
		}
    }

    public function addCommunity($communityID)
    {
		if (!$this->hasCommunity($communityID))
		{
			$community = new Community($communityID);
			if ($org->OrganizationID != -1)
			{
		        $connection = new Connection();
		        $connection->CommunityID = $communityID;
		        $connection->GroupID = $this->GroupID;
		        $connection->ConnectionType = CONNECTIONTYPE_MEMBER;
		        $connection->saveToDB();
			}
		}
    }

    public function addMember($userID)
    {
		if (!$this->hasMember($userID))
		{
			$member = new User($userID);
			if ($member->UserID != -1)
			{
				$connection = new Connection(-1);
   				$connection->UserID = $userID;
		        $connection->GroupID = $this->GroupID;
		        $connection->ConnectionType = CONNECTIONTYPE_MEMBER;
		        $connection->saveToDB();
			}
		}
    }

    public function addAdmin($userID)
    {
    	if (!$this->isOwner($userID))
    	{
			$this->removeMember($userID);

			$member = new User($userID);
			if ($member->UserID != -1)
			{
				$connection = new Connection();
   				$connection->UserID = $userID;
			    $connection->GroupID = $this->GroupID;
			    $connection->ConnectionType = CONNECTIONTYPE_ADMIN;
			    $connection->saveToDB();
			}
		}
    }

    public function sendGroupRequest($groupID, $messageText, $type = CONNECTIONFLAG_TYPE_UNOFFICIAL)
    {
    	Message::sendGroupRequest('Group', $this->GroupID, $groupID, $messageText, $type);
	}

    public function sendOrganizationRequest($orgID, $messageText, $type = CONNECTIONFLAG_TYPE_UNOFFICIAL)
    {
    	Message::sendOrganizationRequest('Group', $this->GroupID, $orgID, $messageText, $type);
	}

    public function requestJoin($userID)
    {
		Message::sendGroupRequest('User', $userID, $this->GroupID);
	}

    public function addUser($userID)
    {
		if (!$this->hasMember($userID))
		{
			$member = new User($userID);
			if ($member->UserID != -1)
			{
				$connection = new Connection();
				$connection->ConnectionType	= CONNECTIONTYPE_MEMBER;
				$connection->GroupID		= $this->GroupID;
				$connection->UserID			= $member->UserID;
				$connection->saveToDB();
			}
		}
    }

    public static function getUserGroups($userID, $owneronly = false)
    {
    	$db = DBConnect::getInstance();
    	if ($owneronly)
    	{
    		$result = $db->query('select g.* from `connection` c inner join `group` g on g.GroupID = c.GroupID ' .
    			'where c.UserID = %d and c.GroupID is not null and (c.ConnectionType = %d or c.ConnectionType = %d)',
    			$userID, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER);
		}
		else
		{
    		$result = $db->query('select g.* from `connection` c inner join `group` g on g.GroupID = c.GroupID ' .
    			'where c.UserID = %d and c.GroupID is not null and (c.ConnectionType = %d or c.ConnectionType = %d or c.ConnectionType = %d)',
    			$userID, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER);
		}
    	$return = array();

    	foreach ($result->Data as $row)
    	{
    		$group = new Group();
    		$group->populateFromArray($row);
    		$return[] = $group;
    	}
    	return $return;
    }

    public function isOwner($userID)
    {
    	return ($this->getOwnerUserID() == $userID) || User::checkEmployer($userID);
    }

	public function getSubgroups()
	{
		$db = DBConnect::getInstance();

		$result = $db->query('SELECT g.* FROM `connection` c inner join `group` g on c.GroupID = g.GroupID ' .
			'where c.ToGroupID = %d and c.ConnectionType = %d', $this->GroupID, CONNECTIONTYPE_MEMBER);

		$return = array();
		foreach ($result->Data as $row)
		{
			$group = new Group();
			$group->populateFromArray($row);

			$return[] = $group;
		}
		return $return;
	}

	public function removeSubgroup($groupID)
	{
		$connections = Connection::getConnections(array('ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'GroupID' => $userID, 'ToGroupID' => $this->GroupID));
    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}
	}

	public static function getGroups($group_statuses = array())
	{
		$db = DBConnect::getInstance();
		$params = array();
		$query  = 'SELECT * FROM `group`';

		if (!empty($group_statuses))
		{
			$query .= ' WHERE ';
			foreach ($group_statuses as $group_status)
			{
				$query .= 'GroupStatus = %d OR ';
				$params[] = $group_status;
			}
			$query = rtrim($query, 'OR ');
		}

		$return = array();
		$result = $db->query($query, $params);
		foreach ($result->Data as $row)
		{
			$group = new Group();
			$group->populateFromArray($row);
			$return[] = $group;
		}

		return $return;
	}

	public function getComments()
	{
		return Comment::getGroupComments($this->GroupID);
	}

	public function getAlbumsCount()
	{
		return Album::getAlbumsCount('Group', $this->GroupID);
	}

	public function getAlbums()
	{
		return Album::getGroupAlbums($this->GroupID);
	}

	public function getGroupMembersCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(ConnectionID) AS cc FROM `connection` WHERE (UserID <> '-1') AND (GroupID = %s)", $this->GroupID);
		return $query->Data['0']['cc'];
	}

    public function getOwner()
    {
    	$cons = Connection::getConnections(array('GroupID' => $this->GroupID, 'ConnectionType' => CONNECTIONTYPE_OWNER));
        if ($cons[0]->UserID != -1)
        {
        	return new User($cons[0]->UserID);
		}
		if ($cons[0]->OrganizationID != -1)
        {
        	return new Organization($cons[0]->OrganizationID);
		}
		return -1;
    }

    public function getOwnerConnection()
    {
        $cons = Connection::getConnections(array('GroupID' => $this->GroupID, 'ConnectionType' => CONNECTIONTYPE_OWNER));
        return $cons[0];
    }

    public function getOwnerType()
    {
        $cons = Connection::getConnections(array('GroupID' => $this->GroupID, 'ConnectionType' => CONNECTIONTYPE_OWNER));
        if ($cons[0]->UserID != -1)
        {
        	return GROUPTYPE_USER;
		}
		if ($cons[0]->OrganizationID != -1)
        {
        	return GROUPTYPE_ORG;
		}
		return -1;
	}

    public function setOwner($ownerid, $ownertype = GROUPTYPE_USER)
    {
        $connections = Connection::getConnections(array('OrganizationID' => $this->OrganizationID, 'ConnectionType' => CONNECTIONTYPE_OWNER));
        $connection = count($connections) ? $connections[0] : new Connection();
        switch ($ownertype)
        {
        	case GROUPTYPE_ORG:
        		$connection->OrganizationID = $ownerid;
        		break;
        	case GROUPTYPE_USER:
        		$connection->UserID = $ownerid;
        		break;
		}
        $connection->GroupID = $this->GroupID;
        $connection->ConnectionType = CONNECTIONTYPE_OWNER;
        $connection->saveToDB();
    }

    public function connectToOrganization($organization_id)
    {
        $connection = new Connection();
        $connection->GroupID = $this->GroupID;
        $connection->OrganizationID = $organization_id;
        $connection->saveToDB();
    }

    public function changeUserStatusInGroup($user_id, $user_status)
    {
		$db = DBConnect::getInstance();
		$db->update('connection', array('UserStatus' => $user_status), 'UserID = %d AND GroupID = %d', $user_id, $this->GroupID);
    }

    public static function nameExists($name, $curgrid = 0)
    {
    	$db = DBConnect::getInstance();
    	$res = $db->query("select `GroupID` from `group` where `GroupName`=%s and `GroupID`<>%s", $name, $curgrid);
    	return ($res->Size > 0);
	}

	public function getGroupNews()
	{
		return News::getGroupNews($this->GroupID);
	}

	public function getGroupNewsDrafts($userID)
	{
		return News::getGroupNewsDrafts($this->GroupID, $userID);
	}

	public function getGroupLocations()
	{
		return Location::getGroupLocations($this->GroupID);
	}

	public static function clearGroupLocations($groupID)
	{
		$db = DBConnect::getInstance();
		$db->delete('location', 'GroupID = %d', $groupID);
	}

	public static function clearOtherSocialGroups($groupID)
	{
		$db = DBConnect::getInstance();
		$db->delete('socialgroup', 'GroupID = %d', $groupID);
	}

    public static function getByGroupName($name)
	{
		$group = new Group();

		if ($name != '')
		{
			$db = DBConnect::getInstance();
			$res = $db->query('SELECT * FROM `group` WHERE GroupName = %s', $name);

			if ($res->Size > 0)
			{
				$group->populateFromArray($res->Data[0]);
			}
		}

		return $group;
	}

    public function getConnectedOrganizationInfo()
    {
        $db = DBConnect::getInstance();

        $query = $db->query("SELECT o.* FROM `connection` JOIN organization AS o USING (OrganizationID) WHERE (GroupID = %s)", $this->GroupID);

        return $query->Data;
    }

	public function getOtherSocialGroups()
	{
		return SocialGroup::getOtherSocialGroups($this->GroupID);
	}

	public function getGroupAlbums()
	{
		return Album::getGroupAlbums($this->GroupID);
	}

	public function getGroupUsers()
	{
		return User::getGroupUsers($this->GroupID);
	}

	public function getGroupMembers()
	{
		$db = DBConnect::getInstance();
		$result = $db->query("SELECT u.*, c.* FROM `connection` c inner join user u on c.UserID = u.UserID where (c.GroupID = %s and c.ConnectionType in (%d, %d, %d))", $this->GroupID, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN);
		$return = array();
		foreach ($result->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
			$connection = new Connection(-1);
			$connection->populateFromArray($row);
			$return[] = $user;
		}
		return $return;
	}

	public function getGroupAdmins()
	{
		$db = DBConnect::getInstance();
		$result = $db->query("SELECT u.*, c.* FROM `connection` c inner join user u on c.UserID = u.UserID where (c.GroupID = %s and c.ConnectionType in (%d, %d))", $this->GroupID, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_ADMIN);
		$return = array();
		foreach ($result->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
			$connection = new Connection(-1);
			$connection->populateFromArray($row);
			$return[] = $user;
		}
		return $return;
	}

	public function getGroupPendingUsers($sort_by = 'UserName', $sort_order = 'ASC')
	{
		return Message::getGroupPendingUsers($this->GroupID, $sort_by, $sort_order);
	}

	public function getGroupSingleUsers($sort_by = 'UserName', $sort_order = 'ASC')
	{
		return User::getGroupSingleUsers($this->GroupID, $sort_by, $sort_order);
	}

	public function getGroupTeams($sort_by = 'TeamName', $sort_order = 'ASC')
	{
		return Team::getGroupTeams($this->GroupID, $sort_by, $sort_order);
	}

	public function getUserStatusInGroup($user_id)
    {
    	$connections = Connection::getConnections(array('ConnectionType' => array(CONNECTIONTYPE_OWNER, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER), 'GroupID' => $this->GroupID, 'UserID' => $user_id));
    	$result = $connections[0]->UserStatus;

    	return $result;
    }

    public function getPhotoCount()
    {
        return Photo::getGroupPhotoCount($this->GroupID);
    }

    public function getVideoCount()
    {
        return Video::getGroupVideoCount($this->GroupID);
    }

	public function getVideoAlbums()
	{
		return VideoAlbum::getGroupVideoAlbums($this->GroupID);
	}

    public function removeUserFromGroupAdminList($user_id)
	{
		$db = DBConnect::getInstance();
		$db->update('connection', array('ConnectionType' => CONNECTIONTYPE_MEMBER), 'UserID = %d AND GroupID = %d', $user_id, $this->GroupID);
	}

	public function suicide()
	{
		$this->clearGroupLocations($this->GroupID);
		$this->clearOtherSocialGroups($this->GroupID);
		$this->delete();
	}

    public function getSentInvitations()
    {
        return SentInvitation::getGroupSentInvitations($this->GroupID);
    }

        public function inviteMember($fromUserID, $userID, $message)
    {
    	return Message::sendGroupInvite($fromUserID, $this->GroupID, $userID, $message);
    }

    public function userIsAdmin($userid, $owner = true)
    {
    	$types = array(CONNECTIONTYPE_ADMIN);

    	if ($owner)
    	{
    		$types[] = CONNECTIONTYPE_OWNER;
    	}

    	$con = Connection::getConnections
    	(
    		array
    		(
                'Flags' => '<> ' . CONNECTIONFLAG_STATUS_SUSPEND,
    			'GroupID' => $this->GroupID,
    			'ConnectionType' => $types,
    			'UserID' => $userid
    		)
    	);

    	if (count($con))
    	{
    		return true;
		}

		return User::checkEmployer($userid);
	}

	public function getGroupPhotos($maxcount = 6)
	{
		$db = DBConnect::getInstance();
		$query = $db->query("select p.PhotoID, p.AlbumID, p.PhotoName, p.PhotoPath, p.PhotoStatus, p.PhotoIsCover FROM photo p INNER JOIN album a ON (a.AlbumID = p.AlbumID) AND (a.GroupID = %s) ORDER BY PhotoID DESC limit $maxcount", $this->GroupID);
		$return = array();
		foreach ($query->Data as $row)
		{
			$photo = new Photo(-1);
			$photo->populateFromArray($row);
			$return[] = $photo;
		}
		return $return;
	}

	public function getPhotos($maxcount = 6)
	{
		return $this->getGroupPhotos($maxcount);
	}

	public function getGroupVideos($maxcount = 6)
	{
		$return = array();

		$db = DBConnect::getInstance();
		$result = $db->query('SELECT v.* FROM `video` AS v INNER JOIN `videoalbum` AS a ON (a.VideoAlbumID = v.VideoAlbumID) AND (a.GroupID = %s) ORDER BY v.VideoID DESC limit ' . $maxcount, $this->GroupID);

		foreach ($result->Data as $row)
		{
			$video = new Video();
			$video->populateFromArray($row);

			$return[] = $video;
		}

		return $return;
	}

	public function getVideos($maxcount = 6)
	{
		return $this->getGroupVideos($maxcount);
	}

	public function getGroupFiles($maxcount = 6)
	{
		$return = array();

		$db = DBConnect::getInstance();
		$result = $db->query('select * from file where GroupID = %d order by `FileID` limit ' . $maxcount, $this->GroupID);

		foreach ($result->Data as $row)
		{
			$file = new File();
			$file->populateFromArray($row);

			$return[] = $file;
		}

		return $return;
	}

	public function getSharedFiles($maxcount = '')
	{
		$shared_files = SharedFile::getGroupFiles($this->GroupID);
		if (!empty($maxcount))
		{
			$shared_files = array_slice($shared_files, 0, $maxcount);
		}

		return $shared_files;
	}

	public function getNewsViewPrivacySettings()
	{
		return News::getGroupViewPrivacySettings($this->GroupID);
	}

	public function getNewsEditPrivacySettings()
	{
		return News::getGroupEditPrivacySettings($this->GroupID);
	}

	public function setNewsViewPrivacySettings($privacy_settings)
	{
		News::setGroupViewPrivacySettings($this->GroupID, $privacy_settings);
	}

	public function setNewsEditPrivacySettings($privacy_settings)
	{
		News::setGroupEditPrivacySettings($this->GroupID, $privacy_settings);
	}

	public function getTags()
	{
		return Tag::getGroupTags($this->GroupID);
	}

	public function checkViewNewsPrivacy()
	{
		global $user;

		if ($this->getNewsViewPrivacySettings() == PRIVACY_PUBLIC)
		{
			$result = true;
		}
		elseif ( ($this->getNewsViewPrivacySettings() == PRIVACY_PRIVATE) && ($this->hasMember($user->UserID)) )
		{
			$result = true;
		}
		else
		{
			$result = false;
		}

		return $result;
	}

	public function checkEditNewsPrivacy()
	{
		global $user;

		if ($this->getNewsEditPrivacySettings() == NEWS_PRIVACY_PUBLIC)
		{
			$result = true;
		}
		elseif ( ($this->getNewsEditPrivacySettings() == NEWS_PRIVACY_ADMINS) && ($this->userIsAdmin($user->UserID)) )
		{
			$result = true;
		}
		elseif ( ($this->getNewsEditPrivacySettings() == NEWS_PRIVACY_MEMBERS) && ($this->hasMember($user->UserID)) )
		{
			$result = true;
		}
		else
		{
			$result = false;
		}

		return $result;
	}

    public function newsBelongsToThisGroup($news_id)
    {
    	$db = DBConnect::getInstance();
		$result = $db->query("SELECT GroupID FROM `news` WHERE NewsID=%d", $news_id);

		return ($result->Data[0]['GroupID'] == $this->GroupID);
	}

	public function deleteNews($news_id)
	{
        if ($this->checkEditNewsPrivacy() && $this->newsBelongsToThisGroup($news_id))
        {
	        $news = new News($news_id);
			$news->deleteNews();
		}
	}

	public function getMembersByCompany($company_name)
	{
        $result = array();

        $db = DBConnect::getInstance();
		$res = $db->query("
			SELECT u.* FROM `user` AS u
			INNER JOIN `company` AS c ON c.UserID = u.UserID
			WHERE c.CompanyName LIKE %p", $company_name);

		foreach ($res->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
            if ($this->hasMember($user->UserID))
            {
				$result[] = $user;
			}
		}

		return $result;
	}

	public function getMembersBySkill($skill_name)
	{
        $result = array();

        $db = DBConnect::getInstance();
		$res = $db->query("
			SELECT u.* FROM `user` AS u
			INNER JOIN `skill` AS s ON s.UserID = u.UserID
			WHERE s.SkillName LIKE %p", $skill_name);

		foreach ($res->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
            if ($this->hasMember($user->UserID))
            {
				$result[] = $user;
			}
		}

		return $result;
	}

	public function getMembersBySchool($school_name)
	{
        $result = array();

        $db = DBConnect::getInstance();
		$res = $db->query("
			SELECT u.* FROM `user` AS u
			INNER JOIN `school` AS s ON s.UserID = u.UserID
			WHERE s.SchoolName LIKE %p", $school_name);

		foreach ($res->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
            if ($this->hasMember($user->UserID))
            {
				$result[] = $user;
			}
		}

		return $result;
	}

	public function getMembersByInterest($interest_name)
	{
        $result = array();

        $db = DBConnect::getInstance();
		$res = $db->query("
			SELECT u.* FROM `user` AS u
			INNER JOIN `connection` AS c ON c.UserID = u.UserID
			WHERE c.GroupID=%d AND u.UserFavouriteInterests LIKE %p", $this->GroupID, $interest_name);

		foreach ($res->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
            if ($this->hasMember($user->UserID))
            {
				$result[] = $user;
			}
		}

		return $result;
	}

	public function getNewMembersCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(ConnectionID) AS cc FROM `connection` WHERE (UserID <> '-1') AND (GroupID = %s) AND (ConnectionType = %d OR ConnectionType = %d) AND (DATEDIFF(CURDATE(), Created) <= %d)", $this->GroupID, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['cc'];
	}

	public function getNewNewsCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(NewsID) AS n FROM `news` WHERE (GroupID = %s) AND (DATEDIFF(CURDATE(), NewsDate) <= %d)", $this->GroupID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['n'];
	}

	public function getNewPhotosCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(PhotoID) AS pp FROM `photo` AS p INNER JOIN `album` AS a ON a.AlbumID = p.AlbumID WHERE (a.GroupID = %s) AND (DATEDIFF(CURDATE(), p.PhotoCreated) <= %d)", $this->GroupID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['pp'];
	}

	public function getNewVideosCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(VideoID) AS vv FROM `video` AS v INNER JOIN `videoalbum` AS a ON a.VideoAlbumID = v.VideoAlbumID WHERE (a.GroupID = %s) AND (DATEDIFF(CURDATE(), v.VideoCreated) <= %d)", $this->GroupID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['vv'];
	}

	public function getNewFilesCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(SharedFileID) AS sf FROM `sharedfile` WHERE (GroupID = %s) AND (DATEDIFF(CURDATE(), Updated) <= %d)", $this->GroupID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['sf'];
	}

	public function getForms()
	{
		return Form::getGroupForms($this->GroupID);
	}

	public function getName()
	{
		return $this->GroupName;
	}
}