<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class Photo Extends Entity
{
	public $PhotoID			= -1;
	public $AlbumID			= -1;
	public $PhotoName		= '';
	public $PhotoPath		= '';
	public $PhotoStatus		= PHOTOSTATUS_NOT_APPROVED;
	public $PhotoIsCover	= false;
	public $PhotoCreated    = CURRENT_TIME;


    public static function getUserPhotoCountRank($userID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select count(*) as cnt, a.UserID from photo v inner join album a on a.AlbumID = v.AlbumID group by a.UserID order by cnt asc');

        for ($i = 0; $i < count($result->Data); $i++)
        {
            if ($userID == $result->Data[$i]['UserID'])
            {
                break;
            }
        }
        return $i + 1;
    }

    public static function getUserPhotoCount($userID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select count(*) as cnt from photo v inner join album a on a.AlbumID = v.AlbumID where a.UserID = %d', $userID);
        return intval($result->Data[0]['cnt']);
    }

    public static function getUserPhotosSize($userID)
    {
    	$size = 0;

        $db = DBConnect::getInstance();
        $result = $db->query('select * from photo v inner join album a on a.AlbumID = v.AlbumID where a.UserID = %d', $userID);
        foreach ($result->Data as $row)
        {
        	$obj = new Photo();
        	$obj->populateFromArray($row);
        	$size += @filesize($obj->getPhotoURL(true)) + @filesize($obj->getPhotoURL(false));
		}

		return $size;
    }


    public static function getGroupPhotoCount($groupID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select count(*) as cnt from photo v inner join album a on a.AlbumID = v.AlbumID where a.GroupID = %d', $groupID);
        return intval($result->Data[0]['cnt']);
    }

    public static function getOrganizationPhotoCount($organizationID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select count(*) as cnt from photo v inner join album a on a.AlbumID = v.AlbumID where a.OrganizationID = %d', $organizationID);
        return intval($result->Data[0]['cnt']);
    }

	public static function getAlbumPhotos($albumID, $first = 0, $last = 999999)
	{
		$return = array();

		$first = is_numeric($first) ? $first : 0;
        $last = is_numeric($last) ? $last : 5;
		if ( ($last -= $first) <= 0)
        {
            $last = 5;
        }

        $db = DBConnect::getInstance();
		$result = $db->query('select * from photo where AlbumID = %d order by `PhotoID` limit ' . $first . ', ' . $last, $albumID);
		foreach ($result->Data as $row)
		{
			$photo = new Photo();
			$photo->populateFromArray($row);

			$return[] = $photo;
		}

		return $return;
	}

	public function getPhotoURL($preview = true)
	{
		return PATH_ALBUM_PICS . '/' . $this->AlbumID . ($preview ? "/previews/" : "/") . $this->PhotoPath;
	}

	public function getPhotoComments()
	{
		return Comment::getPhotoComments($this->PhotoID);
	}

	public function getPhotoCommentsCount()
	{
		return Comment::getPhotoCommentsCount($this->PhotoID);
	}

	public function getAlbum()
	{
		return new Album($this->AlbumID);
	}

	public function getPrevPhotoID()
	{
		$db = DBConnect::getInstance();
		$query = $db->query('SELECT MAX(PhotoID) AS PhotoID FROM `photo` WHERE (AlbumID = %d) AND (PhotoID < %d)', $this->AlbumID, $this->PhotoID);

		return $query->Data[0]['PhotoID'];
	}

	public function getNextPhotoID()
	{
		$db = DBConnect::getInstance();
		$query = $db->query('SELECT PhotoID FROM `photo` WHERE (AlbumID = %d) AND (PhotoID > %d)', $this->AlbumID, $this->PhotoID);

		return $query->Data[0]['PhotoID'];
	}

    public function getTags()
    {
    	return Tag::getTags(TAG_TYPE_PHOTO, $this->PhotoID);
    }

    public static function deleteAlbumPhotos($album_id = -1)
    {
		$db = DBConnect::getInstance();
		$result = $db->query('DELETE FROM `photo` WHERE AlbumID = %d ', $album_id);

		return $result;
    }
}
?>