<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class Team extends Entity
{
	public  $TeamID				= -1;
	public  $GroupID			= -1;
	public  $OrganizationID		= -1;
	public  $TeamName			= '';
	public  $TeamDescription	= '';
	public  $TeamPermissions	= -1;


	public static function getByTeamName($team_name)
	{
		$team = new Team();
		if (!empty($team_name))
		{
			$db = DBConnect::getInstance();
			$res = $db->query('SELECT * FROM `team` WHERE TeamName = %s', $team_name);

			if ($res->Size > 0)
			{
				$team->populateFromArray($res->Data[0]);
			}
		}

		return $team;
	}

    public function getTeamUsers()
    {
        $users = array();

        $db = DBConnect::getInstance();

        $query = "SELECT * FROM `user` AS u
                INNER JOIN `usertoteam` AS utt ON utt.UserID = u.UserID
                WHERE utt.TeamID = %d";

        $result = $db->query($query, $this->TeamID);

    	foreach ($result->Data as $key => $user_data)
    	{
            $user = new User();
            $user->populateFromArray($user_data);
            $users[] = $user;
    	}

        return $users;
    }

    public static function getGroupTeams($group_id, $sort_by = 'TeamName', $sort_order = 'ASC')
    {
        $return = array();

        $db = DBConnect::getInstance();
        $query =
            'SELECT * FROM `team` AS t ' .
            'WHERE GroupID = %d ' .
            'ORDER BY ' . $sort_by . ' ' . $sort_order;

        $result = $db->query($query, $group_id);

        foreach ($result->Data as $row)
        {
            $group_team = new Team();
            $group_team->populateFromArray($row);
            $return[] = $group_team;
        }

        return $return;
    }

    public static function getOrganizationTeams($organization_id, $sort_by = 'TeamName', $sort_order = 'ASC')
    {
        $result = array();

        $db = DBConnect::getInstance();
        $query =
            'SELECT * FROM `team` AS t ' .
            'WHERE OrganizationID = %d ' .
            'ORDER BY ' . $sort_by . ' ' . $sort_order;

        $rs = $db->query($query, $organization_id);

        foreach ($rs->Data as $row)
        {
            $organization_team = new Team();
            $organization_team->populateFromArray($row);
            $result[] = $organization_team;
        }

        return $result;
    }

	public static function getUserTeamInGroup($user_id, $group_id)
	{
		$team = new Team();

		if (!empty($user_id) && !empty($group_id))
		{
			$db = DBConnect::getInstance();
			$query = "SELECT t.* FROM `team` AS t
				INNER JOIN `usertoteam` AS utt ON utt.TeamID=t.TeamID
				INNER JOIN `user` AS u ON u.UserID=utt.UserID
				INNER JOIN `group` AS g ON g.GroupID=t.GroupID
				WHERE g.GroupID = %d AND u.UserID = %d";

			$res = $db->query($query, $group_id, $user_id);

			if ($res->Size > 0)
			{
				$team->populateFromArray($res->Data[0]);
			}
		}

		return $team;
	}

	public static function getUserTeamInOrganization($user_id, $organization_id)
	{
		$team = new Team();

		if (!empty($user_id) && !empty($organization_id))
		{
			$db = DBConnect::getInstance();
			$query = "SELECT t.* FROM `team` AS t
				INNER JOIN `usertoteam` AS utt ON utt.TeamID=t.TeamID
				INNER JOIN `user` AS u ON u.UserID=utt.UserID
				INNER JOIN `organization` AS o ON o.OrganizationID=t.OrganizationID
				WHERE o.OrganizationID = %d AND u.UserID = %d";

			$res = $db->query($query, $organization_id, $user_id);

			if ($res->Size > 0)
			{
				$team->populateFromArray($res->Data[0]);
			}
		}

		return $team;
	}

	public function getGroupTeamUsers()
	{
		return User::getGroupTeamUsers($this->TeamID);
	}

	public function getOrganizationTeamUsers()
	{
		$result = array();

    	$db = DBConnect::getInstance();
    	$query =
    		'SELECT DISTINCT u.* FROM `user` AS u ' .
    		'INNER JOIN `connection` AS c ON c.UserID = u.UserID ' .
    		'INNER JOIN `usertoteam` AS utt ON utt.UserID = u.UserID ' .
    		'INNER JOIN `team` AS t ON t.TeamID = utt.TeamID AND t.OrganizationID = c.OrganizationID ' .
    		'WHERE t.TeamID = %d ' .
    		'ORDER BY t.TeamName ASC';
    	$rs = $db->query($query, $this->TeamID);

    	foreach ($rs->Data as $row)
    	{
    		$group_user = new User();
    		$group_user->populateFromArray($row);
    		$result[] = $group_user;
    	}

    	return $result;
	}

    public static function getFirstGroupTeam($group_id)
    {
        $team = new Team();

        if (!empty($group_id))
        {
            $db = DBConnect::getInstance();

            $query = "SELECT * FROM `team` WHERE GroupID = %d LIMIT 1";

            $res = $db->query($query, $group_id);

            if ($res->Size > 0)
            {
                $team->populateFromArray($res->Data[0]);
            }
        }

        return $team;
    }

    public static function getFirstOrganizationTeam($organization_id)
    {
        $team = new Team();

        if (!empty($organization_id))
        {
            $db = DBConnect::getInstance();

            $query = "SELECT * FROM `team` WHERE OrganizationID = %d LIMIT 1";

            $res = $db->query($query, $organization_id);

            if ($res->Size > 0)
            {
                $team->populateFromArray($res->Data[0]);
            }
        }

        return $team;
    }

    public function removeUserFromGroupTeam($user_id)
	{
		$db = DBConnect::getInstance();

		$query = "SELECT t.TeamID FROM `team` AS t
			INNER JOIN `usertoteam` AS utt ON utt.TeamID=t.TeamID
			INNER JOIN `user` AS u ON u.UserID=utt.UserID
			INNER JOIN `group` AS g ON g.GroupID=t.GroupID
			WHERE g.GroupID = %d AND u.UserID = %d";
		$res = $db->query($query, $this->GroupID, $user_id);

		$team_id = $res->Data[0]['TeamID'];

		$db->delete('usertoteam', 'UserID=%d AND TeamID=%d', $user_id, $team_id);
	}

    public function removeUserFromOrganizationTeam($user_id)
	{
		$db = DBConnect::getInstance();

		$query = "SELECT t.TeamID FROM `team` AS t
			INNER JOIN `usertoteam` AS utt ON utt.TeamID=t.TeamID
			INNER JOIN `user` AS u ON u.UserID=utt.UserID
			INNER JOIN `organization` AS o ON o.OrganizationID=t.OrganizationID
			WHERE o.OrganizationID = %d AND u.UserID = %d";
		$res = $db->query($query, $this->OrganizationID, $user_id);

		$team_id = $res->Data[0]['TeamID'];

		$db->delete('usertoteam', 'UserID=%d AND TeamID=%d', $user_id, $team_id);
	}

	public function addUserToTeam($user_id)
	{
		$result = false;

		if ($user_id > 0)
		{
			if ($this->GroupID > 0)
			{
				$this->removeUserFromGroupTeam($user_id);
			}
			elseif ($this->OrganizationID > 0)
			{
				$this->removeUserFromOrganizationTeam($user_id);
			}

			$db = DBConnect::getInstance();

			$query = "INSERT INTO `usertoteam` VALUES (%d, %d)";
			$result = $db->query($query, $user_id, $this->TeamID);
		}

		return $result;
	}

	public function addUsersToTeam($user_ids = array())
	{
		if (!is_array($user_ids))
		{
			$user_id = $user_ids;
			$this->addUserToTeam($user_id);
		}
		else
		{
			foreach ($user_ids as $key => $user_id)
			{
				$this->addUserToTeam($user_id);
			}
		}
	}

    protected function clearTeamToUserRelationships()
    {
        $db = DBConnect::getInstance();
        $db->delete('usertoteam', 'TeamID = %d', $this->TeamID);
    }

    public function suicide()
    {
        $this->clearTeamToUserRelationships();
        $this->delete();
    }
}
?>